# Welcome to spaceprime


[![image](https://img.shields.io/pypi/v/spaceprime.svg)](https://pypi.python.org/pypi/spaceprime)


**A python package to facilitate spatially explicit coalescent modeling in msprime**


-   Free software: MIT License
-   Documentation: <https://connor-french.github.io/spaceprime>
    
## Background information

- [Suitability to deme size transformation functions](background/trans-fns.md)


## Features

-   TODO
